==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/machinelearningservices/kotlin/FeaturesetContainerEntity.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.machinelearningservices.kotlin

import com.pulumi.azurenative.machinelearningservices.kotlin.outputs.FeaturesetContainerResponse
import com.pulumi.azurenative.machinelearningservices.kotlin.outputs.SystemDataResponse
import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import com.pulumi.azurenative.machinelearningservices.kotlin.outputs.FeaturesetContainerResponse.Companion.toKotlin as featuresetContainerResponseToKotlin
import com.pulumi.azurenative.machinelearningservices.kotlin.outputs.SystemDataResponse.Companion.toKotlin as systemDataResponseToKotlin

/**
 * Builder for [FeaturesetContainerEntity].
 */
@PulumiTagMarker
public class FeaturesetContainerEntityResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: FeaturesetContainerEntityArgs = FeaturesetContainerEntityArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend FeaturesetContainerEntityArgsBuilder.() -> Unit) {
        val builder = FeaturesetContainerEntityArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.opts(block)
    }

    internal fun build(): FeaturesetContainerEntity {
        val builtJavaResource =
            com.pulumi.azurenative.machinelearningservices.FeaturesetContainerEntity(
                this.name,
                this.args.toJava(),
                this.opts.toJava(),
            )
        return FeaturesetContainerEntity(builtJavaResource)
    }
}

/**
 * Azure Resource Manager resource envelope.
 * Azure REST API version: 2023-04-01-preview.
 * Other available API versions: 2023-06-01-preview, 2023-08-01-preview, 2023-10-01.
 * ## Example Usage
 * ### CreateOrUpdate Workspace Featureset Container.
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var featuresetContainerEntity = new AzureNative.MachineLearningServices.FeaturesetContainerEntity("featuresetContainerEntity", new()
 *     {
 *         FeaturesetContainerProperties = new AzureNative.MachineLearningServices.Inputs.FeaturesetContainerArgs
 *         {
 *             Description = "string",
 *             IsArchived = false,
 *             Properties =
 *             {
 *                 { "string", "string" },
 *             },
 *             Tags =
 *             {
 *                 { "string", "string" },
 *             },
 *         },
 *         Name = "string",
 *         ResourceGroupName = "test-rg",
 *         WorkspaceName = "my-aml-workspace",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/machinelearningservices/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := machinelearningservices.NewFeaturesetContainerEntity(ctx, "featuresetContainerEntity", &machinelearningservices.FeaturesetContainerEntityArgs{
 * 			FeaturesetContainerProperties: &machinelearningservices.FeaturesetContainerArgs{
 * 				Description: pulumi.String("string"),
 * 				IsArchived:  pulumi.Bool(false),
 * 				Properties: pulumi.StringMap{
 * 					"string": pulumi.String("string"),
 * 				},
 * 				Tags: pulumi.StringMap{
 * 					"string": pulumi.String("string"),
 * 				},
 * 			},
 * 			Name:              pulumi.String("string"),
 * 			ResourceGroupName: pulumi.String("test-rg"),
 * 			WorkspaceName:     pulumi.String("my-aml-workspace"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.machinelearningservices.FeaturesetContainerEntity;
 * import com.pulumi.azurenative.machinelearningservices.FeaturesetContainerEntityArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var featuresetContainerEntity = new FeaturesetContainerEntity("featuresetContainerEntity", FeaturesetContainerEntityArgs.builder()
 *             .featuresetContainerProperties(Map.ofEntries(
 *                 Map.entry("description", "string"),
 *                 Map.entry("isArchived", false),
 *                 Map.entry("properties", Map.of("string", "string")),
 *                 Map.entry("tags", Map.of("string", "string"))
 *             ))
 *             .name("string")
 *             .resourceGroupName("test-rg")
 *             .workspaceName("my-aml-workspace")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:machinelearningservices:FeaturesetContainerEntity string /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.MachineLearningServices/workspaces/{workspaceName}/featuresets/{name}
 * ```
 */
public class FeaturesetContainerEntity internal constructor(
    override val javaResource:
    com.pulumi.azurenative.machinelearningservices.FeaturesetContainerEntity,
) : KotlinCustomResource(javaResource, FeaturesetContainerEntityMapper) {
    /**
     * [Required] Additional attributes of the entity.
     */
    public val featuresetContainerProperties: Output<FeaturesetContainerResponse>
        get() = javaResource.featuresetContainerProperties().applyValue({ args0 ->
            args0.let({ args0 ->
                featuresetContainerResponseToKotlin(args0)
            })
        })

    /**
     * The name of the resource
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * Azure Resource Manager metadata containing createdBy and modifiedBy information.
     */
    public val systemData: Output<SystemDataResponse>
        get() = javaResource.systemData().applyValue({ args0 ->
            args0.let({ args0 ->
                systemDataResponseToKotlin(args0)
            })
        })

    /**
     * The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })
}

public object FeaturesetContainerEntityMapper : ResourceMapper<FeaturesetContainerEntity> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.machinelearningservices.FeaturesetContainerEntity::class == javaResource::class

    override fun map(javaResource: Resource): FeaturesetContainerEntity =
        FeaturesetContainerEntity(
            javaResource as
                com.pulumi.azurenative.machinelearningservices.FeaturesetContainerEntity,
        )
}

/**
 * @see [FeaturesetContainerEntity].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [FeaturesetContainerEntity].
 */
public suspend fun featuresetContainerEntity(
    name: String,
    block: suspend FeaturesetContainerEntityResourceBuilder.() -> Unit,
): FeaturesetContainerEntity {
    val builder = FeaturesetContainerEntityResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [FeaturesetContainerEntity].
 * @param name The _unique_ name of the resulting resource.
 */
public fun featuresetContainerEntity(name: String): FeaturesetContainerEntity {
    val builder = FeaturesetContainerEntityResourceBuilder()
    builder.name(name)
    return builder.build()
}

==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/machinelearningservices/kotlin/FeaturesetContainerEntity.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.machinelearningservices.kotlin

import com.pulumi.azurenative.machinelearningservices.kotlin.outputs.FeaturesetContainerResponse
import com.pulumi.azurenative.machinelearningservices.kotlin.outputs.SystemDataResponse
import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import com.pulumi.azurenative.machinelearningservices.kotlin.outputs.FeaturesetContainerResponse.Companion.toKotlin as featuresetContainerResponseToKotlin
import com.pulumi.azurenative.machinelearningservices.kotlin.outputs.SystemDataResponse.Companion.toKotlin as systemDataResponseToKotlin

/**
 * Builder for [FeaturesetContainerEntity].
 */
@PulumiTagMarker
public class FeaturesetContainerEntityResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: FeaturesetContainerEntityArgs = FeaturesetContainerEntityArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend FeaturesetContainerEntityArgsBuilder.() -> Unit) {
        val builder = FeaturesetContainerEntityArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.opts(block)
    }

    internal fun build(): FeaturesetContainerEntity {
        val builtJavaResource =
            com.pulumi.azurenative.machinelearningservices.FeaturesetContainerEntity(
                this.name,
                this.args.toJava(),
                this.opts.toJava(),
            )
        return FeaturesetContainerEntity(builtJavaResource)
    }
}

/**
 * Azure Resource Manager resource envelope.
 * Azure REST API version: 2023-04-01-preview.
 * Other available API versions: 2023-06-01-preview, 2023-08-01-preview, 2023-10-01, 2024-01-01-preview.
 * ## Example Usage
 * ### CreateOrUpdate Workspace Featureset Container.
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var featuresetContainerEntity = new AzureNative.MachineLearningServices.FeaturesetContainerEntity("featuresetContainerEntity", new()
 *     {
 *         FeaturesetContainerProperties = new AzureNative.MachineLearningServices.Inputs.FeaturesetContainerArgs
 *         {
 *             Description = "string",
 *             IsArchived = false,
 *             Properties =
 *             {
 *                 { "string", "string" },
 *             },
 *             Tags =
 *             {
 *                 { "string", "string" },
 *             },
 *         },
 *         Name = "string",
 *         ResourceGroupName = "test-rg",
 *         WorkspaceName = "my-aml-workspace",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/machinelearningservices/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := machinelearningservices.NewFeaturesetContainerEntity(ctx, "featuresetContainerEntity", &machinelearningservices.FeaturesetContainerEntityArgs{
 * 			FeaturesetContainerProperties: &machinelearningservices.FeaturesetContainerArgs{
 * 				Description: pulumi.String("string"),
 * 				IsArchived:  pulumi.Bool(false),
 * 				Properties: pulumi.StringMap{
 * 					"string": pulumi.String("string"),
 * 				},
 * 				Tags: pulumi.StringMap{
 * 					"string": pulumi.String("string"),
 * 				},
 * 			},
 * 			Name:              pulumi.String("string"),
 * 			ResourceGroupName: pulumi.String("test-rg"),
 * 			WorkspaceName:     pulumi.String("my-aml-workspace"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.machinelearningservices.FeaturesetContainerEntity;
 * import com.pulumi.azurenative.machinelearningservices.FeaturesetContainerEntityArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var featuresetContainerEntity = new FeaturesetContainerEntity("featuresetContainerEntity", FeaturesetContainerEntityArgs.builder()
 *             .featuresetContainerProperties(Map.ofEntries(
 *                 Map.entry("description", "string"),
 *                 Map.entry("isArchived", false),
 *                 Map.entry("properties", Map.of("string", "string")),
 *                 Map.entry("tags", Map.of("string", "string"))
 *             ))
 *             .name("string")
 *             .resourceGroupName("test-rg")
 *             .workspaceName("my-aml-workspace")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:machinelearningservices:FeaturesetContainerEntity string /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.MachineLearningServices/workspaces/{workspaceName}/featuresets/{name}
 * ```
 */
public class FeaturesetContainerEntity internal constructor(
    override val javaResource:
    com.pulumi.azurenative.machinelearningservices.FeaturesetContainerEntity,
) : KotlinCustomResource(javaResource, FeaturesetContainerEntityMapper) {
    /**
     * [Required] Additional attributes of the entity.
     */
    public val featuresetContainerProperties: Output<FeaturesetContainerResponse>
        get() = javaResource.featuresetContainerProperties().applyValue({ args0 ->
            args0.let({ args0 ->
                featuresetContainerResponseToKotlin(args0)
            })
        })

    /**
     * The name of the resource
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * Azure Resource Manager metadata containing createdBy and modifiedBy information.
     */
    public val systemData: Output<SystemDataResponse>
        get() = javaResource.systemData().applyValue({ args0 ->
            args0.let({ args0 ->
                systemDataResponseToKotlin(args0)
            })
        })

    /**
     * The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })
}

public object FeaturesetContainerEntityMapper : ResourceMapper<FeaturesetContainerEntity> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.machinelearningservices.FeaturesetContainerEntity::class == javaResource::class

    override fun map(javaResource: Resource): FeaturesetContainerEntity =
        FeaturesetContainerEntity(
            javaResource as
                com.pulumi.azurenative.machinelearningservices.FeaturesetContainerEntity,
        )
}

/**
 * @see [FeaturesetContainerEntity].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [FeaturesetContainerEntity].
 */
public suspend fun featuresetContainerEntity(
    name: String,
    block: suspend FeaturesetContainerEntityResourceBuilder.() -> Unit,
): FeaturesetContainerEntity {
    val builder = FeaturesetContainerEntityResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [FeaturesetContainerEntity].
 * @param name The _unique_ name of the resulting resource.
 */
public fun featuresetContainerEntity(name: String): FeaturesetContainerEntity {
    val builder = FeaturesetContainerEntityResourceBuilder()
    builder.name(name)
    return builder.build()
}
